@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -94,6 +96,13 @@ class AgentAuditedClient(AbstractModel):
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
         self.Mail = params.get("Mail")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentBillElem(AbstractModel):
@@ -162,6 +171,13 @@ class AgentBillElem(AbstractModel):
         self.ClientType = params.get("ClientType")
         self.ProjectType = params.get("ProjectType")
         self.ActivityId = params.get("ActivityId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentClientElem(AbstractModel):
@@ -217,6 +233,13 @@ class AgentClientElem(AbstractModel):
         self.Status = params.get("Status")
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentDealElem(AbstractModel):
@@ -363,6 +386,13 @@ class AgentDealElem(AbstractModel):
                 obj = ProductInfoElem()
                 obj._deserialize(item)
                 self.ProductInfo.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentDealNewElem(AbstractModel):
@@ -509,6 +539,13 @@ class AgentDealNewElem(AbstractModel):
                 obj = ProductInfoElem()
                 obj._deserialize(item)
                 self.ProductInfo.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentPayDealsRequest(AbstractModel):
@@ -534,6 +571,13 @@ class AgentPayDealsRequest(AbstractModel):
         self.OwnerUin = params.get("OwnerUin")
         self.AgentPay = params.get("AgentPay")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentPayDealsResponse(AbstractModel):
@@ -551,6 +595,13 @@ class AgentPayDealsResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentSalesmanElem(AbstractModel):
@@ -580,6 +631,13 @@ class AgentSalesmanElem(AbstractModel):
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
         self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentTransferMoneyRequest(AbstractModel):
@@ -601,6 +659,13 @@ class AgentTransferMoneyRequest(AbstractModel):
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
         self.Amount = params.get("Amount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AgentTransferMoneyResponse(AbstractModel):
@@ -618,6 +683,13 @@ class AgentTransferMoneyResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AuditApplyClientRequest(AbstractModel):
@@ -643,6 +715,13 @@ class AuditApplyClientRequest(AbstractModel):
         self.ClientUin = params.get("ClientUin")
         self.AuditResult = params.get("AuditResult")
         self.Note = params.get("Note")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AuditApplyClientResponse(AbstractModel):
@@ -676,6 +755,53 @@ class AuditApplyClientResponse(AbstractModel):
         self.AuditResult = params.get("AuditResult")
         self.AgentTime = params.get("AgentTime")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class ClientBaseElem(AbstractModel):
+    """代客基础信息
+
+    """
+
+    def __init__(self):
+        """
+        :param AgentUin: 代客关联的代理商UIN
+        :type AgentUin: str
+        :param ClientUin: 代客UIN
+        :type ClientUin: str
+        :param ClientRelateType: 代客关联类型 0:代理 1:转售
+        :type ClientRelateType: int
+        :param AgentCooperationMode: 代理商合作模式 0:代理 1:转售
+        :type AgentCooperationMode: int
+        :param AgentCountry: 代理商国家编码 China:中国  其他:海外，如US等
+        :type AgentCountry: str
+        """
+        self.AgentUin = None
+        self.ClientUin = None
+        self.ClientRelateType = None
+        self.AgentCooperationMode = None
+        self.AgentCountry = None
+
+
+    def _deserialize(self, params):
+        self.AgentUin = params.get("AgentUin")
+        self.ClientUin = params.get("ClientUin")
+        self.ClientRelateType = params.get("ClientRelateType")
+        self.AgentCooperationMode = params.get("AgentCooperationMode")
+        self.AgentCountry = params.get("AgentCountry")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreatePayRelationForClientRequest(AbstractModel):
@@ -693,6 +819,13 @@ class CreatePayRelationForClientRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreatePayRelationForClientResponse(AbstractModel):
@@ -710,6 +843,13 @@ class CreatePayRelationForClientResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DealGoodsPriceElem(AbstractModel):
@@ -727,6 +867,13 @@ class DealGoodsPriceElem(AbstractModel):
 
     def _deserialize(self, params):
         self.RealTotalCost = params.get("RealTotalCost")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DealGoodsPriceNewElem(AbstractModel):
@@ -744,6 +891,13 @@ class DealGoodsPriceNewElem(AbstractModel):
 
     def _deserialize(self, params):
         self.RealTotalCost = params.get("RealTotalCost")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentAuditedClientsRequest(AbstractModel):
@@ -809,6 +963,13 @@ class DescribeAgentAuditedClientsRequest(AbstractModel):
         self.ProjectType = params.get("ProjectType")
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentAuditedClientsResponse(AbstractModel):
@@ -839,6 +1000,13 @@ class DescribeAgentAuditedClientsResponse(AbstractModel):
                 self.AgentClientSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentBillsRequest(AbstractModel):
@@ -880,6 +1048,13 @@ class DescribeAgentBillsRequest(AbstractModel):
         self.ClientRemark = params.get("ClientRemark")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentBillsResponse(AbstractModel):
@@ -910,6 +1085,13 @@ class DescribeAgentBillsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.AgentBillSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentClientGradeRequest(AbstractModel):
@@ -927,6 +1109,13 @@ class DescribeAgentClientGradeRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentClientGradeResponse(AbstractModel):
@@ -960,6 +1149,13 @@ class DescribeAgentClientGradeResponse(AbstractModel):
         self.ClientGrade = params.get("ClientGrade")
         self.ClientType = params.get("ClientType")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentClientsRequest(AbstractModel):
@@ -1005,6 +1201,13 @@ class DescribeAgentClientsRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentClientsResponse(AbstractModel):
@@ -1035,6 +1238,13 @@ class DescribeAgentClientsResponse(AbstractModel):
                 self.AgentClientSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentDealsByCacheRequest(AbstractModel):
@@ -1084,6 +1294,13 @@ class DescribeAgentDealsByCacheRequest(AbstractModel):
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
         self.PayerMode = params.get("PayerMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentDealsByCacheResponse(AbstractModel):
@@ -1114,6 +1331,13 @@ class DescribeAgentDealsByCacheResponse(AbstractModel):
                 self.AgentDealSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentDealsCacheRequest(AbstractModel):
@@ -1163,6 +1387,13 @@ class DescribeAgentDealsCacheRequest(AbstractModel):
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
         self.PayerMode = params.get("PayerMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentDealsCacheResponse(AbstractModel):
@@ -1193,6 +1424,13 @@ class DescribeAgentDealsCacheResponse(AbstractModel):
                 self.AgentDealSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentPayDealsRequest(AbstractModel):
@@ -1238,6 +1476,13 @@ class DescribeAgentPayDealsRequest(AbstractModel):
         self.Status = params.get("Status")
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentPayDealsResponse(AbstractModel):
@@ -1268,6 +1513,13 @@ class DescribeAgentPayDealsResponse(AbstractModel):
                 self.AgentPayDealSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentPayDealsV2Request(AbstractModel):
@@ -1313,6 +1565,13 @@ class DescribeAgentPayDealsV2Request(AbstractModel):
         self.Status = params.get("Status")
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentPayDealsV2Response(AbstractModel):
@@ -1343,6 +1602,13 @@ class DescribeAgentPayDealsV2Response(AbstractModel):
                 self.AgentPayDealSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentSelfPayDealsRequest(AbstractModel):
@@ -1388,6 +1654,13 @@ class DescribeAgentSelfPayDealsRequest(AbstractModel):
         self.Order = params.get("Order")
         self.Status = params.get("Status")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentSelfPayDealsResponse(AbstractModel):
@@ -1418,6 +1691,13 @@ class DescribeAgentSelfPayDealsResponse(AbstractModel):
                 self.AgentPayDealSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentSelfPayDealsV2Request(AbstractModel):
@@ -1463,6 +1743,13 @@ class DescribeAgentSelfPayDealsV2Request(AbstractModel):
         self.Order = params.get("Order")
         self.Status = params.get("Status")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAgentSelfPayDealsV2Response(AbstractModel):
@@ -1493,6 +1780,13 @@ class DescribeAgentSelfPayDealsV2Response(AbstractModel):
                 self.AgentPayDealSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeClientBalanceRequest(AbstractModel):
@@ -1510,6 +1804,13 @@ class DescribeClientBalanceRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeClientBalanceResponse(AbstractModel):
@@ -1519,18 +1820,90 @@ class DescribeClientBalanceResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Balance: 账户余额，单位分
+        :param Balance: 账户可用余额，单位分 （可用余额 = 现金余额 - 冻结金额）
         :type Balance: int
+        :param Cash: 账户现金余额，单位分
+        :type Cash: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.Balance = None
+        self.Cash = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
         self.Balance = params.get("Balance")
+        self.Cash = params.get("Cash")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class DescribeClientBaseInfoRequest(AbstractModel):
+    """DescribeClientBaseInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ClientUin: 代客UIN
+        :type ClientUin: str
+        """
+        self.ClientUin = None
+
+
+    def _deserialize(self, params):
+        self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class DescribeClientBaseInfoResponse(AbstractModel):
+    """DescribeClientBaseInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ClientBaseSet: 代客基础信息数组
+        :type ClientBaseSet: list of ClientBaseElem
+        :param TotalCount: 符合条件的代客数
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ClientBaseSet = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("ClientBaseSet") is not None:
+            self.ClientBaseSet = []
+            for item in params.get("ClientBaseSet"):
+                obj = ClientBaseElem()
+                obj._deserialize(item)
+                self.ClientBaseSet.append(obj)
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeRebateInfosRequest(AbstractModel):
@@ -1556,6 +1929,13 @@ class DescribeRebateInfosRequest(AbstractModel):
         self.RebateMonth = params.get("RebateMonth")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeRebateInfosResponse(AbstractModel):
@@ -1586,6 +1966,13 @@ class DescribeRebateInfosResponse(AbstractModel):
                 self.RebateInfoSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeSalesmansRequest(AbstractModel):
@@ -1619,6 +2006,13 @@ class DescribeSalesmansRequest(AbstractModel):
         self.SalesName = params.get("SalesName")
         self.SalesUin = params.get("SalesUin")
         self.OrderDirection = params.get("OrderDirection")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeSalesmansResponse(AbstractModel):
@@ -1649,6 +2043,13 @@ class DescribeSalesmansResponse(AbstractModel):
                 self.AgentSalesmanSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeUnbindClientListRequest(AbstractModel):
@@ -1690,6 +2091,13 @@ class DescribeUnbindClientListRequest(AbstractModel):
         self.ApplyTimeStart = params.get("ApplyTimeStart")
         self.ApplyTimeEnd = params.get("ApplyTimeEnd")
         self.OrderDirection = params.get("OrderDirection")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeUnbindClientListResponse(AbstractModel):
@@ -1720,6 +2128,13 @@ class DescribeUnbindClientListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.UnbindClientList.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyClientRemarkRequest(AbstractModel):
@@ -1741,6 +2156,13 @@ class ModifyClientRemarkRequest(AbstractModel):
     def _deserialize(self, params):
         self.ClientRemark = params.get("ClientRemark")
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyClientRemarkResponse(AbstractModel):
@@ -1758,6 +2180,13 @@ class ModifyClientRemarkResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ProductInfoElem(AbstractModel):
@@ -1779,6 +2208,13 @@ class ProductInfoElem(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RebateInfoElem(AbstractModel):
@@ -1816,6 +2252,13 @@ class RebateInfoElem(AbstractModel):
         self.MonthSales = params.get("MonthSales")
         self.QuarterSales = params.get("QuarterSales")
         self.ExceptionFlag = params.get("ExceptionFlag")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RemovePayRelationForClientRequest(AbstractModel):
@@ -1833,6 +2276,13 @@ class RemovePayRelationForClientRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RemovePayRelationForClientResponse(AbstractModel):
@@ -1850,6 +2300,13 @@ class RemovePayRelationForClientResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class UnbindClientElem(AbstractModel):
@@ -1884,4 +2341,11 @@ class UnbindClientElem(AbstractModel):
         self.Name = params.get("Name")
         self.Status = params.get("Status")
         self.ApplyTime = params.get("ApplyTime")
-        self.ActionTime = params.get("ActionTime")
\ No newline at end of file
+        self.ActionTime = params.get("ActionTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
\ No newline at end of file
